Returns the path to the file index JSON cache file. The file index stores scanned folder results to avoid expensive recursive directory scans on startup.
Returns the path to the file index JSON cache file. The file index stores scanned folder results to avoid expensive recursive directory scans on startup.